@@ -2,6 +2,7 @@ import pytest
 import pkg_resources
 import micromagneticmodel.abstract
 import micromagneticmodel.consts
+import micromagneticmodel.examples
 from .energy import EnergyTerm, Exchange, Zeeman, UniaxialAnisotropy, \
     CubicAnisotropy, Demag, Zeeman, DMI, MagnetoElastic, Energy
 from .dynamics import DynamicsTerm, Precession, Damping, ZhangLi, \
@@ -12,8 +13,8 @@ from .system import System
 
 
 def test():
-    return pytest.main(["-v", "--pyargs",
-                        "micromagneticmodel"])  # pragma: no cover
+    return pytest.main(['-v', '--pyargs',
+                        'micromagneticmodel'])  # pragma: no cover
 
 
 __version__ = pkg_resources.get_distribution(__name__).version
